@@ -33,9 +33,9 @@ import (
 	"github.com/coreos/go-semver/semver"
 	"github.com/mitchellh/copystructure"
 
-	"github.com/twpayne/chezmoi/v2/internal/chezmoierrors"
-	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
-	"github.com/twpayne/chezmoi/v2/internal/chezmoiset"
+	"github.com/twpayne/chezmoi/internal/chezmoierrors"
+	"github.com/twpayne/chezmoi/internal/chezmoilog"
+	"github.com/twpayne/chezmoi/internal/chezmoiset"
 )
 
 // An ExternalType is a type of external source.
@@ -901,9 +901,9 @@ TARGET:
 		case err == nil:
 			// Do nothing.
 		case errors.Is(err, fs.ErrExist):
-			// Do nothing.
+			continue TARGET
 		case errors.Is(err, fs.ErrNotExist):
-			// Do nothing.
+			continue TARGET
 		default:
 			return err
 		}
@@ -1400,7 +1400,7 @@ func (s *SourceState) addExternalDir(ctx context.Context, externalsDirAbsPath Ab
 			return nil
 		case fileInfo.Mode().IsRegular():
 			parentAbsPath, _ := externalAbsPath.Split()
-			return s.addExternal(externalAbsPath, parentAbsPath.TrimSuffix("/").Dir())
+			return s.addExternal(externalAbsPath, parentAbsPath.Dir())
 		case fileInfo.IsDir():
 			return nil
 		default:
